#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2021/3/20 13:48
# @Author : NZL
# @File : DesUtils.py
# @Desc : Des加密解密  导包  pyDes==2.0.1
import logging
import warnings
from nzl_tool.encrypt import pyDes

DES_KEY = 'DesUtils2022'

warnings.simplefilter("ignore")


def des_encrypt(secret_str, des_key_=DES_KEY):
    """
    加密
    :param secret_str: 密文字符串
    :param des_key_: 加密所用的密钥，不设置则使用默认
    :return:
    """
    res = ''
    try:
        des_key = '%s00000000' % str(des_key_)
        des_key = str(des_key)[0:8]
        des_obj = pyDes.des(des_key, pyDes.ECB, des_key, padmode=pyDes.PAD_PKCS5)
        s = secret_str.encode('utf-8')
        secret_bytes = des_obj.encrypt(s)  # 用对象的encrypt方法加密
        res = secret_bytes.hex()
    except Exception as e:
        logging.error("des解密失败，密文：%s ,密钥：%s, e:%s" % (secret_str, des_key_, e))
    return None if res == '' else res


def des_decrypt(secret_str, des_key_=DES_KEY):
    """
    解密
    :param secret_str: 密文
    :param des_key_:解密所用的密钥，不设置则使用默认
    :return:
    """
    res = ''
    try:
        des_key = '%s00000000' % str(des_key_)
        des_key = str(des_key)[0:8]
        des_obj = pyDes.des(des_key, pyDes.ECB, des_key, padmode=pyDes.PAD_PKCS5)
        secret_bytes = bytes.fromhex(secret_str)
        s = des_obj.decrypt(secret_bytes)
        res = s.decode()
    except Exception as e:
        logging.error("des解密失败，密文：%s ,密钥：%s, e:%s" % (secret_str, des_key_, e))
    return None if res == '' else res




import json as _json
import typing as _t
from types import ModuleType


class _CompactJSON:
    """Wrapper around json module that strips whitespace."""

    @staticmethod
    def loads(payload: _t.Union[str, bytes]) -> _t.Any:
        return _json.loads(payload)

    @staticmethod
    def dumps(obj: _t.Any, **kwargs: _t.Any) -> str:
        kwargs.setdefault("ensure_ascii", False)
        kwargs.setdefault("separators", (",", ":"))
        return _json.dumps(obj, **kwargs)


class DeprecatedJSON(ModuleType):
    def __getattribute__(self, item: str) -> _t.Any:
        import warnings

        warnings.warn(
            "Importing 'itsdangerous.json' is deprecated and will be"
            " removed in ItsDangerous 2.1. Use Python's 'json' module"
            " instead.",
            DeprecationWarning,
            stacklevel=2,
        )
        return getattr(_json, item)


json = DeprecatedJSON("json")



#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2022/1/17 10:14
# @Author : NZL
# @File : __init__.py.py
# @Desc :
from .AESUtils import aes_decrypt, aes_encrypt
from .DesUtils import des_decrypt, des_encrypt



import json
import typing as _t

from .encoding import want_bytes
from .exc import BadPayload
from .exc import BadSignature
from .signer import _make_keys_list
from .signer import Signer

_t_str_bytes = _t.Union[str, bytes]
_t_opt_str_bytes = _t.Optional[_t_str_bytes]
_t_kwargs = _t.Dict[str, _t.Any]
_t_opt_kwargs = _t.Optional[_t_kwargs]
_t_signer = _t.Type[Signer]
_t_fallbacks = _t.List[_t.Union[_t_kwargs, _t.Tuple[_t_signer, _t_kwargs], _t_signer]]
_t_load_unsafe = _t.Tuple[bool, _t.Any]
_t_secret_key = _t.Union[_t.Iterable[_t_str_bytes], _t_str_bytes]


def is_text_serializer(serializer: _t.Any) -> bool:
    """Checks whether a serializer generates text or binary."""
    return isinstance(serializer.dumps({}), str)


class Serializer:
    """A serializer wraps a :class:`~itsdangerous.signer.Signer` to
    enable serializing and securely signing data other than bytes. It
    can unsign to verify that the data hasn't been changed.

    The serializer provides :meth:`dumps` and :meth:`loads`, similar to
    :mod:`json`, and by default uses :mod:`json` internally to serialize
    the data to bytes.

    The secret key should be a random string of ``bytes`` and should not
    be saved to code or version control. Different salts should be used
    to distinguish signing in different contexts. See :doc:`/concepts`
    for information about the security of the secret key and salt.

    :param secret_key: The secret key to sign and verify with. Can be a
        list of keys, oldest to newest, to support key rotation.
    :param salt: Extra key to combine with ``secret_key`` to distinguish
        signatures in different contexts.
    :param serializer: An object that provides ``dumps`` and ``loads``
        methods for serializing data to a string. Defaults to
        :attr:`default_serializer`, which defaults to :mod:`json`.
    :param serializer_kwargs: Keyword arguments to pass when calling
        ``serializer.dumps``.
    :param signer: A ``Signer`` class to instantiate when signing data.
        Defaults to :attr:`default_signer`, which defaults to
        :class:`~itsdangerous.signer.Signer`.
    :param signer_kwargs: Keyword arguments to pass when instantiating
        the ``Signer`` class.
    :param fallback_signers: List of signer parameters to try when
        unsigning with the default signer fails. Each item can be a dict
        of ``signer_kwargs``, a ``Signer`` class, or a tuple of
        ``(signer, signer_kwargs)``. Defaults to
        :attr:`default_fallback_signers`.

    .. versionchanged:: 2.0
        Added support for key rotation by passing a list to
        ``secret_key``.

    .. versionchanged:: 2.0
        Removed the default SHA-512 fallback signer from
        ``default_fallback_signers``.

    .. versionchanged:: 1.1
        Added support for ``fallback_signers`` and configured a default
        SHA-512 fallback. This fallback is for users who used the yanked
        1.0.0 release which defaulted to SHA-512.

    .. versionchanged:: 0.14
        The ``signer`` and ``signer_kwargs`` parameters were added to
        the constructor.
    """

    #: The default serialization module to use to serialize data to a
    #: string internally. The default is :mod:`json`, but can be changed
    #: to any object that provides ``dumps`` and ``loads`` methods.
    default_serializer: _t.Any = json

    #: The default ``Signer`` class to instantiate when signing data.
    #: The default is :class:`itsdangerous.signer.Signer`.
    default_signer: _t_signer = Signer

    #: The default fallback signers to try when unsigning fails.
    default_fallback_signers: _t_fallbacks = []

    def __init__(
        self,
        secret_key: _t_secret_key,
        salt: _t_opt_str_bytes = b"itsdangerous",
        serializer: _t.Any = None,
        serializer_kwargs: _t_opt_kwargs = None,
        signer: _t.Optional[_t_signer] = None,
        signer_kwargs: _t_opt_kwargs = None,
        fallback_signers: _t.Optional[_t_fallbacks] = None,
    ):
        #: The list of secret keys to try for verifying signatures, from
        #: oldest to newest. The newest (last) key is used for signing.
        #:
        #: This allows a key rotation system to keep a list of allowed
        #: keys and remove expired ones.
        self.secret_keys: _t.List[bytes] = _make_keys_list(secret_key)

        if salt is not None:
            salt = want_bytes(salt)
            # if salt is None then the signer's default is used

        self.salt = salt

        if serializer is None:
            serializer = self.default_serializer

        self.serializer: _t.Any = serializer
        self.is_text_serializer: bool = is_text_serializer(serializer)

        if signer is None:
            signer = self.default_signer

        self.signer: _t_signer = signer
        self.signer_kwargs: _t_kwargs = signer_kwargs or {}

        if fallback_signers is None:
            fallback_signers = list(self.default_fallback_signers or ())

        self.fallback_signers: _t_fallbacks = fallback_signers
        self.serializer_kwargs: _t_kwargs = serializer_kwargs or {}

    @property
    def secret_key(self) -> bytes:
        """The newest (last) entry in the :attr:`secret_keys` list. This
        is for compatibility from before key rotation support was added.
        """
        return self.secret_keys[-1]

    def load_payload(
        self, payload: bytes, serializer: _t.Optional[_t.Any] = None
    ) -> _t.Any:
        """Loads the encoded object. This function raises
        :class:`.BadPayload` if the payload is not valid. The
        ``serializer`` parameter can be used to override the serializer
        stored on the class. The encoded ``payload`` should always be
        bytes.
        """
        if serializer is None:
            serializer = self.serializer
            is_text = self.is_text_serializer
        else:
            is_text = is_text_serializer(serializer)

        try:
            if is_text:
                return serializer.loads(payload.decode("utf-8"))

            return serializer.loads(payload)
        except Exception as e:
            raise BadPayload(
                "Could not load the payload because an exception"
                " occurred on unserializing the data.",
                original_error=e,
            )

    def dump_payload(self, obj: _t.Any) -> bytes:
        """Dumps the encoded object. The return value is always bytes.
        If the internal serializer returns text, the value will be
        encoded as UTF-8.
        """
        return want_bytes(self.serializer.dumps(obj, **self.serializer_kwargs))

    def make_signer(self, salt: _t_opt_str_bytes = None) -> Signer:
        """Creates a new instance of the signer to be used. The default
        implementation uses the :class:`.Signer` base class.
        """
        if salt is None:
            salt = self.salt

        return self.signer(self.secret_keys, salt=salt, **self.signer_kwargs)

    def iter_unsigners(self, salt: _t_opt_str_bytes = None) -> _t.Iterator[Signer]:
        """Iterates over all signers to be tried for unsigning. Starts
        with the configured signer, then constructs each signer
        specified in ``fallback_signers``.
        """
        if salt is None:
            salt = self.salt

        yield self.make_signer(salt)

        for fallback in self.fallback_signers:
            if isinstance(fallback, dict):
                kwargs = fallback
                fallback = self.signer
            elif isinstance(fallback, tuple):
                fallback, kwargs = fallback
            else:
                kwargs = self.signer_kwargs

            for secret_key in self.secret_keys:
                yield fallback(secret_key, salt=salt, **kwargs)

    def dumps(self, obj: _t.Any, salt: _t_opt_str_bytes = None) -> _t_str_bytes:
        """Returns a signed string serialized with the internal
        serializer. The return value can be either a byte or unicode
        string depending on the format of the internal serializer.
        """
        payload = want_bytes(self.dump_payload(obj))
        rv = self.make_signer(salt).sign(payload)

        if self.is_text_serializer:
            return rv.decode("utf-8")

        return rv

    def dump(self, obj: _t.Any, f: _t.IO, salt: _t_opt_str_bytes = None) -> None:
        """Like :meth:`dumps` but dumps into a file. The file handle has
        to be compatible with what the internal serializer expects.
        """
        f.write(self.dumps(obj, salt))

    def loads(
        self, s: _t_str_bytes, salt: _t_opt_str_bytes = None, **kwargs: _t.Any
    ) -> _t.Any:
        """Reverse of :meth:`dumps`. Raises :exc:`.BadSignature` if the
        signature validation fails.
        """
        s = want_bytes(s)
        last_exception = None

        for signer in self.iter_unsigners(salt):
            try:
                return self.load_payload(signer.unsign(s))
            except BadSignature as err:
                last_exception = err

        raise _t.cast(BadSignature, last_exception)

    def load(self, f: _t.IO, salt: _t_opt_str_bytes = None) -> _t.Any:
        """Like :meth:`loads` but loads from a file."""
        return self.loads(f.read(), salt)

    def loads_unsafe(
        self, s: _t_str_bytes, salt: _t_opt_str_bytes = None
    ) -> _t_load_unsafe:
        """Like :meth:`loads` but without verifying the signature. This
        is potentially very dangerous to use depending on how your
        serializer works. The return value is ``(signature_valid,
        payload)`` instead of just the payload. The first item will be a
        boolean that indicates if the signature is valid. This function
        never fails.

        Use it for debugging only and if you know that your serializer
        module is not exploitable (for example, do not use it with a
        pickle serializer).

        .. versionadded:: 0.15
        """
        return self._loads_unsafe_impl(s, salt)

    def _loads_unsafe_impl(
        self,
        s: _t_str_bytes,
        salt: _t_opt_str_bytes,
        load_kwargs: _t_opt_kwargs = None,
        load_payload_kwargs: _t_opt_kwargs = None,
    ) -> _t_load_unsafe:
        """Low level helper function to implement :meth:`loads_unsafe`
        in serializer subclasses.
        """
        if load_kwargs is None:
            load_kwargs = {}

        try:
            return True, self.loads(s, salt=salt, **load_kwargs)
        except BadSignature as e:
            if e.payload is None:
                return False, None

            if load_payload_kwargs is None:
                load_payload_kwargs = {}

            try:
                return (
                    False,
                    self.load_payload(e.payload, **load_payload_kwargs),
                )
            except BadPayload:
                return False, None

    def load_unsafe(self, f: _t.IO, salt: _t_opt_str_bytes = None) -> _t_load_unsafe:
        """Like :meth:`loads_unsafe` but loads from a file.

        .. versionadded:: 0.15
        """
        return self.loads_unsafe(f.read(), salt=salt)



#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2022/1/6 9:14
# @Author : NZL
# @File : mysql_tools.py
# @Desc :
import logging
import warnings
import pymysql

warnings.simplefilter("ignore")


class mysql_tool:
    driver = pymysql
    """The my_mysql is a tool for mysql connect."""

    def __init__(self, host, user, database, password, port=3306, default_character_set="utf-8"):
        self.host = host
        self.user = user
        self.database = database
        self.password = password
        self.port = port
        self.default_character_set = default_character_set

    def _connect(self):
        try:
            return self.driver.connect(host=self.host, port=self.port, user=self.user, passwd=self.password,
                                       db=self.database, charset='utf8')
        except AttributeError:
            logging.error("No connect method found in self.driver module")

    def my_fetchall(self, sql, args=None, return_type=None):
        rows = []
        try:
            con = self._connect()
            if return_type == "dict":
                cur = con.cursor(self.driver.cursors.DictCursor)
            else:
                cur = con.cursor()
            try:
                if ";" not in sql:
                    logging.warning('mysql_tool.my_fetchall: sql not end with \";\";')
                cur.execute(sql, args)
                rows = cur.fetchall()
                rows = [r for r in rows]
                print("my_fetchall sql is %s" % cur._executed)
                logging.debug("dmy_fetchall sql is %s" % cur._executed)
            except self.driver.Error as error:
                logging.error('mysql_tool.my_fetchall: sql:' + sql + ';' + str(error))
            finally:
                con.close()
        except self.driver.Error as error:
            logging.error('mysql_tool.my_fetchall: default.cnf error:' + str(error))
        if str(rows) == "[(None,)]":
            rows = []
        return rows

    def my_fetchone(self, sql, args=None, return_type=None):
        row = []
        try:
            con = self._connect()
            if return_type == "dict":
                cur = con.cursor(self.driver.cursors.DictCursor)
            else:
                cur = con.cursor()
            try:
                if ";" not in sql:
                    logging.warning('mysql_tool.my_fetchone: sql not end with \";\";')
                cur.execute(sql, args)
                row = cur.fetchone()
                print(cur._executed)
                logging.info("my_fetchone sql is %s" % cur._executed)
            except self.driver.Error as error:
                logging.error("mysql_tool.my_fetchone: sql = %s ; error= %s" % (cur._last_executed, str(error)))
                raise error
            finally:
                con.close()
        except self.driver.Error as error:
            logging.error('mysql_tool.my_fetchone: default.cnf error:' + str(error))
        if row is None:
            row = []
        if str(row) == "(None,)":
            row = []
        return row

    def my_fetchone_new(self, sql_list, args=None, return_type=None):
        row_list = []
        try:
            con = self._connect()
            if return_type == "dict":
                cur = con.cursor(self.driver.cursors.DictCursor)
            else:
                cur = con.cursor()

            for sql in sql_list:
                if ";" not in sql:
                    logging.warning('mysql_tool.my_fetchone: sql not end with \";\";')
                try:
                    cur.execute(sql, args)
                    row = cur.fetchone()
                    row_list.append(row)
                    logging.info("my_fetchone_new sql is %s" % cur._executed)
                except self.driver.Error as error:
                    logging.error('mysql_tool.my_fetchone: sql:' + str(error))
                    con.close()
                    break
            try:
                con.close()
            except Exception as e:
                pass
        except self.driver.Error as error:
            logging.error('mysql_tool.my_fetchone: default.cnf error:' + str(error))
        return row_list

    def exe_update(self, table, colomns, conditions):
        """

        :param table: 表名
        :param colomns: 更新列
        :param conditions: 条件
        :return:
        """
        sql = "update {} set ".format(table)
        handled_item = 0
        try:
            con = self._connect()
            cur = con.cursor()
            try:
                cols = []
                vals = []
                for k, v in colomns.items():
                    if v is not None:
                        if v == "now()":
                            col = "{}=now()".format(k)
                            cols.append(col)
                        else:
                            col = "{}=%s".format(k)
                            cols.append(col)
                            vals.append(v)
                cons = []
                for k, v in conditions.items():
                    wheres = "{}=%s".format(k)
                    cons.append(wheres)
                    vals.append(v)

                sql = "{} {} where {};".format(sql, ",".join(cols), ",".join(cons))
                print(sql)

                handled_item = cur.execute(sql, vals)
                logging.debug("execute sql is %s" % cur._executed)
            except self.driver.Error as error:
                logging.error('mysql_tool.execute except: sql:' + sql + ';\n' + str(error))
                return -1
            except Exception as error:
                logging.error("exe_update error: sql = %s ; error= %s" % (cur._executed, str(error)))
            finally:
                con.commit()
                con.close()
        except Exception as error:
            logging.error('mysql_tool.execute: default.cnf error:' + sql + ';' + str(error))
            return -1
        return handled_item

    def execute(self, sql, args=None):
        """

        :param args:
        :param sql: type must be str.
            if update success, return count of update rows.
            if delete success, return count of delete rows.
            if insert success, return 1.
            else return 0.

        :return:
        """
        handled_item = 0
        try:
            con = self._connect()
            cur = con.cursor()
            try:
                if ";" not in sql:
                    logging.warning('mysql_tool.execute: sql not end with \";\";')
                handled_item = cur.execute(sql, args)
                logging.error("execute sql is %s" % cur._executed)
            except self.driver.Error as error:
                return -1
            except Exception as error:
                logging.error('mysql_tool.execute except: sql:' + sql + ';\n' + str(error))
            finally:
                con.commit()
                con.close()
        except Exception as error:
            logging.error('mysql_tool.execute: default.cnf error:' + sql + ';' + str(error))
            return -1
        return handled_item

    def insert(self, sql, args=None):
        """
        insert action
        :return:
        """
        handled_item = 0
        try:
            con = self._connect()
            cur = con.cursor()
            try:
                cur.execute(sql, args)
                handled_item = cur.lastrowid
                logging.info("insert sql is %s" % cur._executed)
            except self.driver.Error as error:
                logging.error('mysql_tool.execute: sql:' + sql + str(error))
            finally:
                con.commit()
                con.close()
        except self.driver.Error as error:
            logging.error('mysql_tool.execute: default.cnf error:' + str(error))
        return handled_item

    def execute_transaction(self, array_sql_action, args=None):
        """

        :param args:
        :param array_sql_action:
            The format is a single SQL, or list ﹣ SQL
        All the list SQL executed successfully, return len (list_sql)
        :return:
        """
        handled_item = 0
        try:
            con = self._connect()
            cur = con.cursor()
            sql = ""
            try:
                con.autocommit(False)
                if type(array_sql_action) is list:
                    i = 1
                    for item in array_sql_action:
                        sql = item
                        if ";" not in sql:
                            logging.warning('mysql_tool.execute_transaction: sql not end with \";\";')
                        if args is not None:
                            handled_item = handled_item + cur.execute(sql, args[i - 1])
                        else:
                            handled_item = handled_item + cur.execute(sql)
                        logging.info("execute_transaction sql %s is %s" % (i, cur._executed))
                        i = i + 1
                else:
                    handled_item = cur.execute(array_sql_action)
            except self.driver.Error as error:
                handled_item = -1
                con.rollback()
                logging.error('mysql_tool.execute_transaction: sql: %s : %s' % (sql, str(error)))
            finally:
                con.commit()
                con.close()
        except self.driver.Error as error:
            logging.error('mysql_tool.execute_transaction: default.cnf error:' + str(error))
        return handled_item




import base64
import string
import struct
import typing as _t

from .exc import BadData

_t_str_bytes = _t.Union[str, bytes]


def want_bytes(
    s: _t_str_bytes, encoding: str = "utf-8", errors: str = "strict"
) -> bytes:
    if isinstance(s, str):
        s = s.encode(encoding, errors)

    return s


def base64_encode(string: _t_str_bytes) -> bytes:
    """Base64 encode a string of bytes or text. The resulting bytes are
    safe to use in URLs.
    """
    string = want_bytes(string)
    return base64.urlsafe_b64encode(string).rstrip(b"=")


def base64_decode(string: _t_str_bytes) -> bytes:
    """Base64 decode a URL-safe string of bytes or text. The result is
    bytes.
    """
    string = want_bytes(string, encoding="ascii", errors="ignore")
    string += b"=" * (-len(string) % 4)

    try:
        return base64.urlsafe_b64decode(string)
    except (TypeError, ValueError):
        raise BadData("Invalid base64-encoded data")


# The alphabet used by base64.urlsafe_*
_base64_alphabet = f"{string.ascii_letters}{string.digits}-_=".encode("ascii")

_int64_struct = struct.Struct(">Q")
_int_to_bytes = _int64_struct.pack
_bytes_to_int = _t.cast("_t.Callable[[bytes], _t.Tuple[int]]", _int64_struct.unpack)


def int_to_bytes(num: int) -> bytes:
    return _int_to_bytes(num).lstrip(b"\x00")


def bytes_to_int(bytestr: bytes) -> int:
    return _bytes_to_int(bytestr.rjust(8, b"\x00"))[0]



import hashlib
import time
import warnings
from datetime import datetime
from datetime import timezone
from decimal import Decimal
from numbers import Real

from ._json import _CompactJSON
from .encoding import base64_decode
from .encoding import base64_encode
from .encoding import want_bytes
from .exc import BadData
from .exc import BadHeader
from .exc import BadPayload
from .exc import BadSignature
from .exc import SignatureExpired
from .serializer import Serializer
from .signer import HMACAlgorithm
from .signer import NoneAlgorithm


class JSONWebSignatureSerializer(Serializer):
    """This serializer implements JSON Web Signature (JWS) support. Only
    supports the JWS Compact Serialization.

    .. deprecated:: 2.0
        Will be removed in ItsDangerous 2.1. Use a dedicated library
        such as authlib.
    """

    jws_algorithms = {
        "HS256": HMACAlgorithm(hashlib.sha256),
        "HS384": HMACAlgorithm(hashlib.sha384),
        "HS512": HMACAlgorithm(hashlib.sha512),
        "none": NoneAlgorithm(),
    }

    #: The default algorithm to use for signature generation
    default_algorithm = "HS512"

    default_serializer = _CompactJSON

    def __init__(
        self,
        secret_key,
        salt=None,
        serializer=None,
        serializer_kwargs=None,
        signer=None,
        signer_kwargs=None,
        algorithm_name=None,
    ):
        warnings.warn(
            "JWS support is deprecated and will be removed in"
            " ItsDangerous 2.1. Use a dedicated JWS/JWT library such as"
            " authlib.",
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(
            secret_key,
            salt=salt,
            serializer=serializer,
            serializer_kwargs=serializer_kwargs,
            signer=signer,
            signer_kwargs=signer_kwargs,
        )

        if algorithm_name is None:
            algorithm_name = self.default_algorithm

        self.algorithm_name = algorithm_name
        self.algorithm = self.make_algorithm(algorithm_name)

    def load_payload(self, payload, serializer=None, return_header=False):
        payload = want_bytes(payload)

        if b"." not in payload:
            raise BadPayload('No "." found in value')

        base64d_header, base64d_payload = payload.split(b".", 1)

        try:
            json_header = base64_decode(base64d_header)
        except Exception as e:
            raise BadHeader(
                "Could not base64 decode the header because of an exception",
                original_error=e,
            )

        try:
            json_payload = base64_decode(base64d_payload)
        except Exception as e:
            raise BadPayload(
                "Could not base64 decode the payload because of an exception",
                original_error=e,
            )

        try:
            header = super().load_payload(json_header, serializer=_CompactJSON)
        except BadData as e:
            raise BadHeader(
                "Could not unserialize header because it was malformed",
                original_error=e,
            )

        if not isinstance(header, dict):
            raise BadHeader("Header payload is not a JSON object", header=header)

        payload = super().load_payload(json_payload, serializer=serializer)

        if return_header:
            return payload, header

        return payload

    def dump_payload(self, header, obj):
        base64d_header = base64_encode(
            self.serializer.dumps(header, **self.serializer_kwargs)
        )
        base64d_payload = base64_encode(
            self.serializer.dumps(obj, **self.serializer_kwargs)
        )
        return base64d_header + b"." + base64d_payload

    def make_algorithm(self, algorithm_name):
        try:
            return self.jws_algorithms[algorithm_name]
        except KeyError:
            raise NotImplementedError("Algorithm not supported")

    def make_signer(self, salt=None, algorithm=None):
        if salt is None:
            salt = self.salt

        key_derivation = "none" if salt is None else None

        if algorithm is None:
            algorithm = self.algorithm

        return self.signer(
            self.secret_keys,
            salt=salt,
            sep=".",
            key_derivation=key_derivation,
            algorithm=algorithm,
        )

    def make_header(self, header_fields):
        header = header_fields.copy() if header_fields else {}
        header["alg"] = self.algorithm_name
        return header

    def dumps(self, obj, salt=None, header_fields=None):
        """Like :meth:`.Serializer.dumps` but creates a JSON Web
        Signature. It also allows for specifying additional fields to be
        included in the JWS header.
        """
        header = self.make_header(header_fields)
        signer = self.make_signer(salt, self.algorithm)
        return signer.sign(self.dump_payload(header, obj))

    def loads(self, s, salt=None, return_header=False):
        """Reverse of :meth:`dumps`. If requested via ``return_header``
        it will return a tuple of payload and header.
        """
        payload, header = self.load_payload(
            self.make_signer(salt, self.algorithm).unsign(want_bytes(s)),
            return_header=True,
        )

        if header.get("alg") != self.algorithm_name:
            raise BadHeader("Algorithm mismatch", header=header, payload=payload)

        if return_header:
            return payload, header

        return payload

    def loads_unsafe(self, s, salt=None, return_header=False):
        kwargs = {"return_header": return_header}
        return self._loads_unsafe_impl(s, salt, kwargs, kwargs)


class TimedJSONWebSignatureSerializer(JSONWebSignatureSerializer):
    """Works like the regular :class:`JSONWebSignatureSerializer` but
    also records the time of the signing and can be used to expire
    signatures.

    JWS currently does not specify this behavior but it mentions a
    possible extension like this in the spec. Expiry date is encoded
    into the header similar to what's specified in `draft-ietf-oauth
    -json-web-token <http://self-issued.info/docs/draft-ietf-oauth-json
    -web-token.html#expDef>`_.
    """

    DEFAULT_EXPIRES_IN = 3600

    def __init__(self, secret_key, expires_in=None, **kwargs):
        super().__init__(secret_key, **kwargs)

        if expires_in is None:
            expires_in = self.DEFAULT_EXPIRES_IN

        self.expires_in = expires_in

    def make_header(self, header_fields):
        header = super().make_header(header_fields)
        iat = self.now()
        exp = iat + self.expires_in
        header["iat"] = iat
        header["exp"] = exp
        return header

    def loads(self, s, salt=None, return_header=False):
        payload, header = super().loads(s, salt, return_header=True)

        if "exp" not in header:
            raise BadSignature("Missing expiry date", payload=payload)

        int_date_error = BadHeader("Expiry date is not an IntDate", payload=payload)

        try:
            header["exp"] = int(header["exp"])
        except ValueError:
            raise int_date_error

        if header["exp"] < 0:
            raise int_date_error

        if header["exp"] < self.now():
            raise SignatureExpired(
                "Signature expired",
                payload=payload,
                date_signed=self.get_issue_date(header),
            )

        if return_header:
            return payload, header

        return payload

    def get_issue_date(self, header):
        """If the header contains the ``iat`` field, return the date the
        signature was issued, as a timezone-aware
        :class:`datetime.datetime` in UTC.

        .. versionchanged:: 2.0
            The timestamp is returned as a timezone-aware ``datetime``
            in UTC rather than a naive ``datetime`` assumed to be UTC.
        """
        rv = header.get("iat")

        if isinstance(rv, (Real, Decimal)):
            return datetime.fromtimestamp(int(rv), tz=timezone.utc)

    def now(self):
        return int(time.time())



#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2022/1/6 9:06
# @Author : NZL
# @File : setup.py.py
# @Desc :
import setuptools

universal = 2

setuptools.setup(
    name="nzl_tools",
    version="1.0.4",
    author="nzl",
    author_email="nzl0379@163.com",
    description="工具包",
    packages=setuptools.find_packages()
)

# python setup.py sdist  打包命令
# python setup.py sdist bdist_wheel --universal 打包命令
# python -m twine upload dist/*   上传命令



#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2022/1/6 9:13
# @Author : NZL
# @File : __init__.py.py
# @Desc :

from .mysql import mysql_tool
from .encrypt import aes_decrypt, aes_encrypt, des_decrypt, des_encrypt
from .jwt import json, base64_decode, base64_encode, want_bytes, BadData, BadHeader, BadPayload, BadSignature, BadTimeSignature, SignatureExpired, Serializer, JSONWebSignatureSerializer, TimedJSONWebSignatureSerializer, HMACAlgorithm, NoneAlgorithm, TimedSerializer, TimestampSigner, URLSafeSerializer, URLSafeTimedSerializer



#!D:/Code/python
# -*- coding: utf-8 -*-
# @Time :2020/12/16 10:45
# @Author : NZL
# @File : AESUtils.py
# @Desc : AES加密工具   导包  pycryptodome==3.12.0
import Crypto.Cipher.AES
import json
import base64
import logging
import warnings

warnings.simplefilter("ignore")

KEY = 'AESUtils2022'


class AesEncrypt(object):

    def __init__(self, key):
        self.key = key
        if len(self.key) < 16:
            self.key = '%s0000000000000000' % self.key
        self.key = str(self.key[0:16]).encode("utf-8")

    def encrypt(self, data):
        data = json.dumps(data).replace('"', '')
        mode = Crypto.Cipher.AES.MODE_ECB
        padding = lambda s: s + (16 - len(s) % 16) * chr(16 - len(s) % 16)
        crypts = Crypto.Cipher.AES.new(self.key, mode)
        cipher_text = crypts.encrypt(padding(data).encode("utf-8"))
        return base64.b64encode(cipher_text).decode("utf-8")

    def decrypt(self, data):
        crypts = Crypto.Cipher.AES.new(self.key, Crypto.Cipher.AES.MODE_ECB)
        decryptBytes = base64.b64decode(data)
        meg = crypts.decrypt(decryptBytes).decode('utf-8')
        return meg[:-ord(meg[-1])]


def aes_decrypt(ciphertext, key=KEY):
    """
    解密
    :param ciphertext: 密文内容
    :param key: 解密所用的密钥，不设置则使用默认
    :return:
    """
    try:
        aes = AesEncrypt(key)
        res = str(aes.decrypt(ciphertext))
        res_len = len(res)
        frond_char = res[0:1]
        end_char = res[res_len - 1:res_len]
        if end_char == '"':
            res = res[0: res_len - 1]
        if frond_char == '"':
            res = res[1: len(res)]
        return str(res.encode('utf8').decode('unicode_escape'))
    except Exception as e:
        logging.error('AES加密出错：%s' % e)
        return None


def aes_encrypt(content, key=KEY):
    """
    加密
    :param content:  需要加密的内容
    :param key: 加密所用的密钥，不设置则使用默认
    :return:
    """
    try:
        aes = AesEncrypt(key)
        return aes.encrypt(content)
    except Exception as e:
        logging.error('AES解密出错：%s' % e)
        return None

